from __future__ import annotations


from .v1_create_security_group_params import V1CreateParams as V1CreateParams

from .v1_create_security_group_resp import V1CreateResponse as V1CreateResponse

from .create_security_group_rules_params import V1CreateRuleParams as V1CreateRuleParams

from .create_security_group_rules_resp import V1CreateRuleResponse as V1CreateRuleResponse

from .attach_security_group_rules_params import V1AttachRuleParams as V1AttachRuleParams

from .attach_detach_generic_response import GenericSuccessResponse as GenericSuccessResponse


from .security_group_list_by_vpc_params import SecurityGroupListByVpcParams as SecurityGroupListByVpcParams
from .security_group_list_by_vpc_response import SecurityGroupListByVpcResponse as SecurityGroupListByVpcResponse


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    certificate_list = client.certs.with_raw_response.list(
        vpc_id = "Enter the VPC ID"
    )

    print(f"{certificate_list.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")





    #  vpc_id = "krn:vm:colo-1:1330618268:64151bfb-efcc-4c55-914e-1e497c7fb602:instance:ca633d8f-c370-49d7-88d5-c7e9fecc4760"


from typing import Optional

from ..._models import BaseModel

__all__ = ["PodCreateResponse"]


class PodCreateResponse(BaseModel):
    message: Optional[str] = None

    pod_id: Optional[str] = None
    """The ID of the newly created pod."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    add_zone = client.v1.zone.with_raw_response.create(
        zonename="enter the zone_name",
        type="enter the type", #private
        vpcid="enter the vpc_id",
        subnetid="enter the subnet_id"   
    )

    print(f"Successfully added the zone{add_zone.json()}")

except Exception as e:
    print(f"Exception: {e}")




from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcCreatePortParams"]


class HighlvlvpcCreatePortParams(TypedDict, total=False):
    floating_ip: Required[bool]
    """Whether to allocate and associate a new floating IP to this port."""

    name: Required[str]
    """Name for the new port."""

    network_id: Required[str]
    """The KRN of the network to associate with the port."""

    subnet_id: Required[str]
    """The KRN of the subnet to associate with the port and assign an IP from."""

    vpc_id: Required[str]
    """The KRN of the VPC where the port will be created."""

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]




from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

from .qos_params import QosParam
from .source_params import SourceParam

__all__ = ["VolumeCreateParams"]


class VolumeCreateParams(TypedDict, total=False):
    availability_zone: Required[str]
    """Availability zone for the volume."""

    multiattach: Required[bool]
    """Whether the volume can be attached to multiple instances."""

    name: Required[str]
    """Name of the volume."""

    size: Required[int]
    """Size of the volume in GB."""

    volumetype: str
    """Type of the volume."""

    description: Optional[str]
    """Description of the volume."""

    metadata: Dict[str, str]
    """Metadata key-value pairs for the volume."""

    qos: QosParam
    """Quality of Service (QoS) settings for the volume."""

    source: SourceParam
    """Source from which the volume is created."""



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)

try:
    create_tg_resp = client.lb.create_target_group(
        target_group_name="enter-your-target-group-name",
        vpc_id="enter vpc_krn",

        x_region="enter the region",
        # x_region possible values "In-Bangalore-1" 


        # Health monitor (API expects: type, delay, timeout, name)
        health_monitor={},

        # Backend members (API expects: name, address, protocol_port)
        members=[]
    )

    print(f"Successfully created Target Group: {create_tg_resp}")

except Exception as e:
    print(f"Error has occurred: {e}")


# examples of health monitor and members:

            # "name": "tg-hm-1",
            # "h_type": "HTTP",      # MUST be TCP / UDP / HTTP
            # "timeout": 5,
            # "delay": 10   



            # {
            #     "name": "member-1",
            #     "address": "10.0.4.175",
            #     "protocol_port": 5000,
            #     "weight": 1
            # },
            # {
            #     "name": "member-2",
            #     "address": "10.0.4.190",
            #     "protocol_port": 5000,
            #     "weight": 1
            # }


from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._types import FileTypes
from ..._utils import PropertyInfo

__all__ = ["CertUpdateParams"]


class CertUpdateParams(TypedDict, total=False):
    x_vpc_id: Required[Annotated[str, PropertyInfo(alias="X-Vpc-Id")]]

    cert_file: Annotated[FileTypes, PropertyInfo(alias="certFile")]

    flag: str


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load the API key from .env file
load_dotenv()
api_key = os.getenv("API_KEY")

# Create a client instance
client = KrutrimClient(api_key=api_key)

try:
    # Create a new pod with the specified parameters
    pod_resp = client.kpod.pod.create(
        container_disk_size="enter disk size",                             
        expose_http_ports="enter http ports",                             
        expose_tcp_ports="enter tcp ports",                               
        flavor_name="enter flavour name",                
        has_encrypt_volume=True,                              
        has_jupyter_notebook=bool,                 #enter eg. true or false           
        has_ssh_access=bool,                        #enter eg. true or false          
        pod_name="enter pod name",                                      
        environment_variables=[                              
            {"name": "VAR_NAME", "value": "VALUE"}
        ],
        pod_template_id=1,                                    
        region="enter region", 
        # x_region possible values "In-Bangalore-1"                             
        sshkey_name="enter sshkeyname",                           
        volume_disk_size="enter volumedisk size",                                  
        volume_mount_path="enter volume mount path",                      
    )

    print(f"Pod created successfully.\nResponse:\n{pod_resp}")

except Exception as e:
    print("Error creating pod:")
    print(e)

    

    










from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SourceParam"]


class SourceParam(TypedDict, total=False):
    id: Required[str]
    """KRN or ID of the source (image, volume, or snapshot)."""

    type: Required[Literal["image", "volume", "snapshot"]]
    """Type of source."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")

client = KrutrimClient(api_key=api_key)

try:

    create_in_bucket_response = client.highlvlvpc.upload_image_s3(

        disk_format="enter the format",  
        image="enter presigned url",
        x_region = "enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"{create_in_bucket_response}")

except Exception as e:
    print(f"Exception: {e}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx
import json
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.dns.v1.zone import vpc_add_params, vpc_remove_params

__all__ = ["VpcResource", "AsyncVpcResource"]


class VpcResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VpcResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return VpcResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VpcResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return VpcResourceWithStreamingResponse(self)

    def add(
        self,
        zoneid: str,
        *,
        vpcinfo: list[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Add VPC to Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/dns/v1/zone/{zoneid}/vpc",
            body=maybe_transform({"vpcinfo": vpcinfo}, vpc_add_params.VpcAddParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def remove(
        self,
        zoneid: str,
        *,
        vpcinfo: list[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Remove VPC from Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/dns/v1/zone/{zoneid}/vpc",
            body=maybe_transform({"vpcinfo": vpcinfo}, vpc_remove_params.VpcRemoveParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncVpcResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVpcResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVpcResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVpcResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return AsyncVpcResourceWithStreamingResponse(self)

    async def add(
        self,
        zoneid: str,
        *,
        vpcinfo: list[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Add VPC to Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/dns/v1/zone/{zoneid}/vpc",
            body=await async_maybe_transform({"vpcinfo": vpcinfo}, vpc_add_params.VpcAddParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def remove(
        self,
        zoneid: str,
        *,
        vpcinfo: list[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Remove VPC from Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/dns/v1/zone/{zoneid}/vpc",
            body=await async_maybe_transform({"vpcinfo": vpcinfo}, vpc_remove_params.VpcRemoveParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class VpcResourceWithRawResponse:
    def __init__(self, vpc: VpcResource) -> None:
        self._vpc = vpc

        self.add = to_raw_response_wrapper(
            vpc.add,
        )
        self.remove = to_raw_response_wrapper(
            vpc.remove,
        )


class AsyncVpcResourceWithRawResponse:
    def __init__(self, vpc: AsyncVpcResource) -> None:
        self._vpc = vpc

        self.add = async_to_raw_response_wrapper(
            vpc.add,
        )
        self.remove = async_to_raw_response_wrapper(
            vpc.remove,
        )


class VpcResourceWithStreamingResponse:
    def __init__(self, vpc: VpcResource) -> None:
        self._vpc = vpc

        self.add = to_streamed_response_wrapper(
            vpc.add,
        )
        self.remove = to_streamed_response_wrapper(
            vpc.remove,
        )


class AsyncVpcResourceWithStreamingResponse:
    def __init__(self, vpc: AsyncVpcResource) -> None:
        self._vpc = vpc

        self.add = async_to_streamed_response_wrapper(
            vpc.add,
        )
        self.remove = async_to_streamed_response_wrapper(
            vpc.remove,
        )



from __future__ import annotations
from typing_extensions import Required, TypedDict
from ..._models import BaseModel

__all__ = ["HighlvlvpcCreateImageResponse"]

class HighlvlvpcCreateImageResponse(BaseModel):
    image: Required[str]
    """The image ID or URL returned by the API"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo
from .volume_param import VolumeParam
from .policy_param import PolicyParam

__all__ = ["V1UpdateLaunchTemplateParams"]


class V1UpdateLaunchTemplateParams(TypedDict, total=False):
    template_id: Required[str]

    template_name: Required[str]

    boot_volume_size: Annotated[str, PropertyInfo(alias="bootVolumeSize")]

    policy: Iterable[PolicyParam]

    qos: Dict[str, object]

    vm_volume_disk_size: str

    volume_size: Annotated[Iterable[VolumeParam], PropertyInfo(alias="volumeSize")]

    x_region: str




from typing import List, Optional

from ..._models import BaseModel
from .vpc_detail import VpcDetail

__all__ = ["HighlvlvpcSearchVpcsResponse"]


class HighlvlvpcSearchVpcsResponse(BaseModel):
    page: Optional[int] = None
    """The current page number."""

    size: Optional[int] = None
    """The number of items per page."""

    total_count: Optional[int] = None
    """The total number of VPCs matching the filter."""

    total_pages: Optional[int] = None
    """The total number of pages."""

    vpcs: Optional[List[VpcDetail]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict, Required

from ..._utils import PropertyInfo

__all__ = ["VolumeParam"]


class VolumeParam(TypedDict, total=False):
    count: Required[int]

    volume_name: Annotated[str, PropertyInfo(alias="volumeName")]

    volume_size: Required[Annotated[int, PropertyInfo(alias="volumeSize")]]

    volume_type: Annotated[str, PropertyInfo(alias="volumeType")]


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    delete_volume_resp = client.kbs.delete_volume(
        k_tenant_id = "Enter the VPC ID",
        id = "Enter the Volume ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Volume Deleted Successfully")
except Exception as e:
    print(f"Exception has occured:  {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try: 
    Get_Vpc_task_status_resp = client.highlvlvpc.get_vpc_task_status(
        task_id = "Enter the Task ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Get VPC task status executed successfully : {Get_Vpc_task_status_resp}")

except Exception as e:
    print(f"Exception  {e}")    


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    list_access_keys_resp = client.kos.accessKeys.list(
        
    )

    print(f"Access Keys List: {list_access_keys_resp}")

except Exception as e:
    print(f"Error has occurred: {e}")






from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["QosParam", "Bandwidth", "Iops"]


class Bandwidth(TypedDict, total=False):
    read_bytes_sec: Required[int]
    """Read bandwidth in bytes per second."""

    write_bytes_sec: Required[int]
    """Write bandwidth in bytes per second."""


class Iops(TypedDict, total=False):
    read_iops_sec: Required[int]
    """Read IOPS per second."""

    write_iops_sec: Required[int]
    """Write IOPS per second."""


class QosParam(TypedDict, total=False):
    bandwidth: Bandwidth
    """Bandwidth settings for QoS."""

    iops: Iops
    """IOPS settings for QoS."""



from __future__ import annotations

from typing import Any
from typing_extensions import TypedDict, Annotated
from ..._utils import PropertyInfo

__all__ = ["PolicyParam"]


class PolicyParam(TypedDict, total=False):
    """
    Flexible ASG policy definition.
    Backend supports multiple policy shapes.
    """

    # Metric-based scaling
    predefined_metric_specification: Annotated[
        dict[str, Any],
        PropertyInfo(alias="PredefinedMetricSpecification"),
    ]

    up_scale_target_value: Annotated[
        int,
        PropertyInfo(alias="UpScaleTargetValue"),
    ]

    down_scale_target_value: Annotated[
        int,
        PropertyInfo(alias="DownScaleTargetValue"),
    ]

    scale_out_cooldown: Annotated[
        int,
        PropertyInfo(alias="ScaleOutCooldown"),
    ]

    scale_in_cooldown: Annotated[
        int,
        PropertyInfo(alias="ScaleInCooldown"),
    ]

    # Scheduled / custom policies
    predefined_metric_type: Annotated[
        str,
        PropertyInfo(alias="PredefinedMetricType"),
    ]

    up_scale_time: Annotated[
        str,
        PropertyInfo(alias="UpScaleTime"),
    ]

    down_scale_time: Annotated[
        str,
        PropertyInfo(alias="DownScaleTime"),
    ]



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    detach_security_group_rules_resp = client.securityGroup.detach_rule(
        ruleid ="Enter the Security Group Rule ID",
        securityid = "Enter the Security Group ID",
        vpcid = "Enter the VPC ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Rule detached successfully")
    delete_rule_resp = client.securityGroup.delete_rule(
        securitygroupruleid  = "Enter the rule ID",
        x_region = "Enter the region",
         # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )   

    print(f"Rule deleted successfully")
except Exception as e:
    print(f"Exception has occurred:  {e}")


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    create_access_keys_resp = client.kos.accessKeys.create_access_keys(
        key_name="enter key name",          
        region="enter the region",         
        x_region_id="enter the region id"    
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    
    
    
    print(f"Successfully created the Access Key: {create_access_keys_resp}")
    

except Exception as e:
    print(f"Error has occurred: {e}")




from __future__ import annotations

from typing import Dict

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.kos.buckets.bucket_create_params import BucketCreateParams
from ...types.kos.buckets.bucket_create_response import BucketCreateResponse
from ...types.kos.buckets.bucket_list_response import BucketListResponse



__all__ = ["BucketsResource", "AsyncBucketsResource"]


class BucketsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BucketsResourceWithRawResponse:
       
        return BucketsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BucketsResourceWithStreamingResponse:
        
        return BucketsResourceWithStreamingResponse(self)
    def validate_create_bucket_params(self, *, name: str, region: str, x_region_id: str) -> None:
    # Ensure the bucket name is a non-empty string
        if not isinstance(name, str) or not name.strip():
            raise ValueError("'name' must be a non-empty string.")
    
    # Ensure the region is a non-empty string
        if not isinstance(region, str) or not region.strip():
            raise ValueError("'region' must be a non-empty string.")
    
    # Ensure the region ID is a non-empty string
        if not isinstance(x_region_id, str) or not x_region_id.strip():
            raise ValueError("'x_region_id' must be a non-empty string.")

    def validate_delete_bucket_params(self, *, bucket_krn: str, x_region_id: str) -> None:
    # Ensure the bucket KRN is a non-empty string
        if not isinstance(bucket_krn, str) or not bucket_krn.strip():
            raise ValueError("'bucket_krn' must be a non-empty string.")
    
    # Ensure the region ID is a non-empty string
        if not isinstance(x_region_id, str) or not x_region_id.strip():
            raise ValueError("'x_region_id' must be a non-empty string.")
        

    def create_bucket(
        self,
        *,
        name: str,
        region: str,
        x_region_id: str,
        anonymous_access: bool | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        tags: Dict[str, str] | NotGiven = NOT_GIVEN,
        versioning: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BucketCreateResponse:
        """
        Create a new bucket

        Args:
          name: The name of the bucket.

          region: The region where the bucket will be created.

          anonymous_access: Whether anonymous access is allowed for the bucket.

          description: A description for the bucket.

          tags: Key-value tags associated with the bucket.

          versioning: Whether versioning is enabled for the bucket.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_create_bucket_params(name=name, region=region, x_region_id=x_region_id)
        extra_headers = {"x-region-id": x_region_id, **(extra_headers or {})}
        return self._post(
            "/kos/v1/buckets",
            body=maybe_transform(
                {
                    "name": name,
                    "region": region,
                    "anonymous_access": anonymous_access,
                    "description": description,
                    "tags": tags,
                    "versioning": versioning,
                },
                BucketCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BucketCreateResponse,
        )

    def list(
        self,
        *,
        
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BucketListResponse:
        """List all buckets for the current user"""
        return self._get(
            "/kos/v1/buckets",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BucketListResponse,
        )

    def delete_bucket(
        self,
        bucket_krn: str,
        *,
        x_region_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> dict:
        """
        Delete a bucket by its KRN (KOS Resource Name)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not bucket_krn:
            raise VxalueError(f"Expected a non-empty value for `bucket_krn` but received {bucket_krn!r}")
        self.validate_delete_bucket_params(bucket_krn=bucket_krn, x_region_id=x_region_id)    
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region-id": x_region_id})
        self._delete(
            f"/kos/v1/buckets/{bucket_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
        return {"bucket_krn": bucket_krn}


class AsyncBucketsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBucketsResourceWithRawResponse:
        
        return AsyncBucketsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBucketsResourceWithStreamingResponse:
        
        return AsyncBucketsResourceWithStreamingResponse(self)
    async def validate_create_bucket_params(self, *, name: str, region: str, x_region_id: str) -> None:
        """
        Validate parameters for creating a bucket.
        """
        if not isinstance(name, str) or not name.strip():
            raise ValueError("'name' must be a non-empty string.")
        
        if not isinstance(region, str) or not region.strip():
            raise ValueError("'region' must be a non-empty string.")
        
        if not isinstance(x_region_id, str) or not x_region_id.strip():
            raise ValueError("'x_region_id' must be a non-empty string.")

    async def validate_delete_bucket_params(self, *, bucket_krn: str, x_region_id: str) -> None:
        """
        Validate parameters for deleting a bucket.
        """
        if not isinstance(bucket_krn, str) or not bucket_krn.strip():
            raise ValueError("'bucket_krn' must be a non-empty string.")
        
        if not isinstance(x_region_id, str) or not x_region_id.strip():
            raise ValueError("'x_region_id' must be a non-empty string.")


    async def create_bucket(
        self,
        *,
        name: str,
        region: str,
        x_region_id: str,
        anonymous_access: bool | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        tags: Dict[str, str] | NotGiven = NOT_GIVEN,
        versioning: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BucketCreateResponse:
        """
        Create a new bucket

        Args:
          name: The name of the bucket.

          region: The region where the bucket will be created.

          anonymous_access: Whether anonymous access is allowed for the bucket.

          description: A description for the bucket.

          tags: Key-value tags associated with the bucket.

          versioning: Whether versioning is enabled for the bucket.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_create_bucket_params(name=name, region=region, x_region_id=x_region_id)
        extra_headers = {"x-region-id": x_region_id, **(extra_headers or {})}
        return await self._post(
            "/kos/v1/buckets",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "region": region,
                    "anonymous_access": anonymous_access,
                    "description": description,
                    "tags": tags,
                    "versioning": versioning,
                },
                BucketCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BucketCreateResponse,
        )

    async def list(
        self,
        *,
        
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BucketListResponse:
        """List all buckets for the current user"""
        return await self._get(
            "/kos/v1/buckets",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BucketListResponse,
        )

    async def delete_bucket(
        self,
        bucket_krn: str,
        *,
        x_region_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> dict:
        """
        Delete a bucket by its KRN (KOS Resource Name)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not bucket_krn:
            raise ValueError(f"Expected a non-empty value for `bucket_krn` but received {bucket_krn!r}")
        await self.validate_delete_bucket_params(bucket_krn=bucket_krn, x_region_id=x_region_id)
    
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region-id": x_region_id})
        await self._delete(
            f"/kos/v1/buckets/{bucket_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
        return {"bucket_krn": bucket_krn}



class BucketsResourceWithRawResponse:
    def __init__(self, buckets: BucketsResource) -> None:
        self._buckets = buckets

        self.create_bucket= to_raw_response_wrapper(
            buckets.create_bucket,
        )
        self.list = to_raw_response_wrapper(
            buckets.list,
        )
        self.delete_bucket= to_raw_response_wrapper(
            buckets.delete_bucket,
        )


class AsyncBucketsResourceWithRawResponse:
    def __init__(self, buckets: AsyncBucketsResource) -> None:
        self._buckets = buckets

        self.create_bucket = async_to_raw_response_wrapper(
            buckets.create_bucket,
        )
        self.list = async_to_raw_response_wrapper(
            buckets.list,
        )
        self.delete_bucket= async_to_raw_response_wrapper(
            buckets.delete_bucket,
        )


class BucketsResourceWithStreamingResponse:
    def __init__(self, buckets: BucketsResource) -> None:
        self._buckets = buckets

        self.create_bucket = to_streamed_response_wrapper(
            buckets.create_bucket,
        )
        self.list = to_streamed_response_wrapper(
            buckets.list,
        )
        self.delete_bucket = to_streamed_response_wrapper(
            buckets.delete_bucket,
        )


class AsyncBucketsResourceWithStreamingResponse:
    def __init__(self, buckets: AsyncBucketsResource) -> None:
        self._buckets = buckets

        self.create_bucket = async_to_streamed_response_wrapper(
            buckets.create_bucket,
        )
        self.list = async_to_streamed_response_wrapper(
            buckets.list,
        )
        self.delete_bucket= async_to_streamed_response_wrapper(
            buckets.delete_bucket,
        )








from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcListInstanceInfoParams"]


class HighlvlvpcListInstanceInfoParams(TypedDict, total=False):
    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    page: int
    """Page number for pagination."""

    page_size: Annotated[int, PropertyInfo(alias="pageSize")]
    """Number of instances per page."""

    vpc_id: str
    """KRN of the VPC to filter instances."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo
from .policy_param import PolicyParam
from .volume_param import VolumeParam

__all__ = ["V1UpdateAsgParams"]


class V1UpdateAsgParams(TypedDict, total=False):
    asg_krn: str

    asg_name: str

    attach_floating_ip: bool

    boot_volume_size: Annotated[str, PropertyInfo(alias="bootVolumeSize")]

    image_krn: str

    instance_name: Annotated[str, PropertyInfo(alias="instanceName")]

    instance_type: Annotated[str, PropertyInfo(alias="instanceType")]

    instance_type_id: Annotated[str, PropertyInfo(alias="instanceTypeId")]

    max: int

    min: int

    network_krn: str

    policy: Iterable[PolicyParam]

    region: str

    save_as_template: bool

    security_groups: SequenceNotStr[str]

    sshkey_name: str

    subnet_id: str

    tags: Iterable[object]

    vm_volume_disk_size: str

    volume_name: Annotated[str, PropertyInfo(alias="volumeName")]

    volume_size: Annotated[Iterable[VolumeParam], PropertyInfo(alias="volumeSize")]

    vpc_krn: str


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    create_port_response = client.highlvlvpc.create_port(
        floating_ip = False,
        name = "Enter the Port Name",
        network_id = "Enter the Network ID",
        subnet_id =  "Enter the Subnet ID",
        vpc_id = "Enter the VPC ID",
        x_region = "Enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully created the port:  {create_port_response}")
except Exception as e:
    print(f"Exception has occurred:  {e}")


from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcCreateImageParams"]

class HighlvlvpcCreateImageParams(TypedDict, total=False):
    name: Required[str]
    """The name for the image to be created."""

    instance_krn: Required[str]
    """The KRN of the instance to create the image from."""

    description: Annotated[str, PropertyInfo(alias="description")]
    """Optional description for the image."""




from .highlvlvpc import (
    HighlvlvpcResource,
    AsyncHighlvlvpcResource,
    HighlvlvpcResourceWithRawResponse,
    AsyncHighlvlvpcResourceWithRawResponse,
    HighlvlvpcResourceWithStreamingResponse,
    AsyncHighlvlvpcResourceWithStreamingResponse,
)

from .securityGroup import (
    SecurityGroupResource,
    AsyncSecurityGroupResource,
    AsyncSecurityGroupResourceWithStreamingResponse,
    SecurityGroupResourceWithStreamingResponse,
    AsyncSecurityGroupResourceWithRawResponse,
    SecurityGroupResourceWithRawResponse
)

from .kbs import (
    KbsResource,
    AsyncKbsResource,
    AsyncKbsResourceWithStreamingResponse,
    KbsResourceWithStreamingResponse,
    AsyncKbsResourceWithRawResponse,
    KbsResourceWithRawResponse
)
from .startStopVM import (
    StartStopResource,
    StartStopResourceWithRawResponse,
    StartStopResourceWithStreamingResponse,
    AsyncStartStopResource,
    AsyncStartStopResourceWithRawResponse,
    AsyncStartStopResourceWithStreamingResponse
)


from .sshkey import(
    SshkeysResource,
    AsyncSshkeysResource,
    SshkeysResourceWithRawResponse,
    AsyncSshkeysResourceWithRawResponse,
    SshkeysResourceWithStreamingResponse,
    AsyncSshkeysResourceWithStreamingResponse
)


 
# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .kks import (
    KksResource,
    AsyncKksResource,
    KksResourceWithRawResponse,
    AsyncKksResourceWithRawResponse,
    KksResourceWithStreamingResponse,
    AsyncKksResourceWithStreamingResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .dns import (
    DNSResource,
    AsyncDNSResource,
    DNSResourceWithRawResponse,
    AsyncDNSResourceWithRawResponse,
    DNSResourceWithStreamingResponse,
    AsyncDNSResourceWithStreamingResponse,
)

from .kcm import (
    CertsResource,
    AsyncCertsResource,
    CertsResourceWithRawResponse,
    AsyncCertsResourceWithRawResponse,
    CertsResourceWithStreamingResponse,
    AsyncCertsResourceWithStreamingResponse,
)

from .asg import (
    AsgResource,
    AsyncAsgResource,
    AsgResourceWithRawResponse,
    AsyncAsgResourceWithRawResponse,
    AsgResourceWithStreamingResponse,
    AsyncAsgResourceWithStreamingResponse,
)



__all__ = [
    "HighlvlvpcResource",
    "AsyncHighlvlvpcResource",
    "HighlvlvpcResourceWithRawResponse",
    "AsyncHighlvlvpcResourceWithRawResponse",
    "HighlvlvpcResourceWithStreamingResponse",
    "AsyncHighlvlvpcResourceWithStreamingResponse",
    "SecurityGroupResource",
    "AsyncSecurityGroupResource",
    "AsyncSecurityGroupResourceWithStreamingResponse",
    "SecurityGroupResourceWithStreamingResponse",
    "AsyncSecurityGroupResourceWithRawResponse",
    "SecurityGroupResourceWithRawResponse",
    "KbsResource",
    "AsyncKbsResource",
    "AsyncKbsResourceWithStreamingResponse",
    "KbsResourceWithStreamingResponse",
    "AsyncKbsResourceWithRawResponse",
    "KbsResourceWithRawResponse",
    "StartStopResource",
    "StartStopResourceWithRawResponse",
    "StartStopResourceWithStreamingResponse",
    "AsyncStartStopResource",
    "AsyncStartStopResourceWithRawResponse",
    "AsyncStartStopResourceWithStreamingResponse",
    "SshkeysResource",
    "AsyncSshkeysResource",
    "SshkeysResourceWithRawResponse",
    "AsyncSshkeysResourceWithRawResponse",
    "SshkeysResourceWithStreamingResponse",
    "AsyncSshkeysResourceWithStreamingResponse",
    "KksResource",
    "AsyncKksResource",
    "KksResourceWithRawResponse",
    "AsyncKksResourceWithRawResponse",
    "KksResourceWithStreamingResponse",
    "AsyncKksResourceWithStreamingResponse",        
    "DNSResource",
    "AsyncDNSResource",
    "DNSResourceWithRawResponse",
    "AsyncDNSResourceWithRawResponse",
    "DNSResourceWithStreamingResponse",
    "AsyncDNSResourceWithStreamingResponse",
    "CertsResource",
    "AsyncCertsResource",
    "CertsResourceWithRawResponse",
    "AsyncCertsResourceWithRawResponse",
    "CertsResourceWithStreamingResponse",
    "AsyncCertsResourceWithStreamingResponse",
    "AsgResource",
    "AsyncAsgResource",
    "AsgResourceWithRawResponse",
    "AsyncAsgResourceWithRawResponse",
    "AsgResourceWithStreamingResponse",
    "AsyncAsgResourceWithStreamingResponse",
]



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)



try:
    highlvlvpc_delete_vpc_response = client.highlvlvpc.delete_vpc(
        vpc_id="Enter the VPC ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Deleted the VPC successfully")
except Exception as e:
    print(f"Exception:  {e}")    


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    add_vpc = client.v1.zone.vpc.with_raw_response.add(
        vpcinfo=["krn:vpc:In-Bangalore-1:0259427492:92945705-e555-4666-a253-d7ccd47c6107:vpc:eda7c905-de43-435c-8ac3-e9ce80b76224"],
        zoneid="krn:pdns:In-Bangalore-1:0259427492:92945705-e555-4666-a253-d7ccd47c6107:pdns_zone:75516d66-bfbd-470e-8921-b15b7af8434d"  
    )

    print(f"Successfully added the zone: {add_vpc.json()}")

except Exception as e:
    print(f"Exception: {e}")



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)
try:
    resp = client.lb.with_raw_response.list_load_balancers_by_vpc(
        x_region="enter the x_region",
        vpc_krn="enter vpc krn"
    )
    print("Response:", resp.json())
except Exception as e:
    print(f"Error has occurred: {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["SecurityGroupListByVpcParams"]


class SecurityGroupListByVpcParams(TypedDict, total=False):
    x_region: Required[Annotated[str, PropertyInfo(alias="x-region")]]

    limit: int
    """The maximum number of records to return (for pagination)."""

    offset: int
    """The number of records to skip from the beginning of the list (for pagination)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["SshkeyCreateResponse"]


class SshkeyCreateResponse(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the SSH key."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """The timestamp when the SSH key was created."""

    fingerprint: Optional[str] = None
    """The SHA256 fingerprint of the public key."""

    key_name: Optional[str] = FieldInfo(alias="keyName", default=None)
    """The name of the SSH key."""

    public_key: Optional[str] = FieldInfo(alias="publicKey", default=None)
    """The public SSH key string."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key = api_key)

try: 
    list_image_resp = client.highlvlvpc.list_image(
        region_id = "enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Successfully searched for the instance:  {list_image_resp}")
except Exception as e:
    print(f"Exception has occured: {e}")




from typing import Dict, List, Optional
from datetime import datetime

from .qos import Qos
from .source import Source
from ..._models import BaseModel

__all__ = ["VolumeDetail", "Attachment"]


class Attachment(BaseModel):
    device: Optional[str] = None

    instance_id: Optional[str] = None


class VolumeDetail(BaseModel):
    id: Optional[str] = None
    """Unique identifier (UUID) of the volume."""

    attachments: Optional[List[Attachment]] = None
    """List of instances to which the volume is attached."""

    availability_zone: Optional[str] = None
    """Availability zone of the volume."""

    created_at: Optional[datetime] = None
    """Timestamp of volume creation."""

    krn: Optional[str] = None
    """Krutrim Resource Name (KRN) of the volume."""

    metadata: Optional[Dict[str, str]] = None
    """Metadata key-value pairs for the volume."""

    multiattach: Optional[bool] = None
    """Whether the volume can be attached to multiple instances."""

    name: Optional[str] = None
    """Name of the volume."""

    qos: Optional[Qos] = None
    """Quality of Service (QoS) settings for the volume."""

    size: Optional[int] = None
    """Size of the volume in GB."""

    source: Optional[Source] = None
    """Source from which the volume is created."""

    status: Optional[str] = None
    """Current status of the volume."""

    updated_at: Optional[datetime] = None
    """Timestamp of last volume update."""

    volumetype: Optional[str] = None
    """Type of the volume."""



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:

    list_buckets_resp = client.kos.buckets.list()
    print(f"Buckets: {list_buckets_resp}")

except Exception as e:
    print(f"Error has occurred: {e}")




from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcDeleteInstanceParams"]


class HighlvlvpcDeleteInstanceParams(TypedDict, total=False):
    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    instance_krn: Annotated[Optional[str], PropertyInfo(alias="instanceKrn")]
    """The KRN of the instance to be deleted."""

    instance_name: Annotated[Optional[str], PropertyInfo(alias="instanceName")]
    """The name of the instance to be deleted."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    Create_VPC_resp = client.highlvlvpc.create_vpc(
         network={
            "name": "Enter the Network Name",
            "admin_state_up": True,
        },
        security_group={
            "name": "Enter the Security Group Name",
            "description": "Enter the Securiy group description",
        },
        security_group_rule={
            "direction": "ingress",
            "ethertypes": "IPv4",
            "protocol": "TCP",
            "portMinRange": 22,
            "portMaxRange": 22,
            "remoteIPPrefix": "0.0.0.0/0"
            },
        
        subnet={
            "cidr": "10.0.38.0/25",
            "gateway_ip": "10.0.38.2",
            "name": "Enter the Subnet Name",
            "description": "Enter the Subnet Description",
            "ip_version": 4,
            "ingress": False,
            "egress": False,
        },
        vpc={
            "name": "Enter the VPC Name",
            "description": "Enter the VPC Description",
            "enabled": True,
        },
        x_region = "Enter the region",
        timeout = 60000
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully created the VPC:  {Create_VPC_resp}")

except Exception as e:
    print(f"Exception occured in creating the VPC:  {e}")


from __future__ import annotations

from typing_extensions import Literal

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from ..types.startStopVM import v1_perform_action_params
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.startStopVM.v1_perform_action_response import V1PerformActionResponse

__all__ = ["StartStopResource", "AsyncStartStopResource"]


class StartStopResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> StartStopResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/start_stop-python#accessing-raw-response-data-eg-headers
        """
        return StartStopResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> StartStopResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/start_stop-python#with_streaming_response
        """
        return StartStopResourceWithStreamingResponse(self)


    def validate_perform_action_parameters(
    self,
    instance_krn: str,
    action: Literal["start", "stop", "reboot"],
    x_region: str,
    extra_headers: Optional[dict] = None,
    extra_query: Optional[dict] = None,
    extra_body: Optional[dict] = None,
    timeout: Union[float, int, httpx.Timeout, None, type(NOT_GIVEN)] = None,
    ) -> None:
        if not isinstance(instance_krn, str):
            raise ValueError("'instance_krn' must be a string.")

        if action not in ("start", "stop", "reboot"):
            raise ValueError("'action' must be one of: 'start', 'stop', or 'reboot'.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

    def perform_action(
        self,
        instance_krn: str,
        *,
        action: Literal["start", "stop", "reboot"],
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1PerformActionResponse:
        """
        Perform an action (e.g., stop) on a VM instance

        Args:
          action: The action to perform on the VM instance.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not instance_krn:
            raise ValueError(f"Expected a non-empty value for `instance_krn` but received {instance_krn!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        self.validate_perform_action_parameters(
        instance_krn = instance_krn,
        action = action,
        x_region = x_region,
        extra_headers = extra_headers,
        extra_query = extra_query,
        extra_body = extra_body,
        timeout = timeout,
            )
        return self._put(
            f"/vm/v1/instance/{instance_krn}",
            body=maybe_transform({"action": action}, v1_perform_action_params.V1PerformActionParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1PerformActionResponse,
        )


class AsyncStartStopResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncStartStopResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/start_stop-python#accessing-raw-response-data-eg-headers
        """
        return AsyncStartStopResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncStartStopResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/start_stop-python#with_streaming_response
        """
        return AsyncStartStopResourceWithStreamingResponse(self)

    async def validate_perform_action_parameters(
    self,
    instance_krn: str,
    action: Literal["start", "stop", "reboot"],
    x_region: str,
    extra_headers: Optional[dict] = None,
    extra_query: Optional[dict] = None,
    extra_body: Optional[dict] = None,
    timeout: Union[float, int, httpx.Timeout, None, type(NOT_GIVEN)] = None,
    ) -> None:
        if not isinstance(instance_krn, str):
            raise ValueError("'instance_krn' must be a string.")

        if action not in ("start", "stop", "reboot"):
            raise ValueError("'action' must be one of: 'start', 'stop', or 'reboot'.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")


    async def perform_action(
        self,
        instance_krn: str,
        *,
        action: Literal["start", "stop", "reboot"],
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1PerformActionResponse:
        """
        Perform an action (e.g., stop) on a VM instance

        Args:
          action: The action to perform on the VM instance.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not instance_krn:
            raise ValueError(f"Expected a non-empty value for `instance_krn` but received {instance_krn!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        await self.validate_perform_action_parameters(
        instance_krn = instance_krn,
        action = action,
        x_region = x_region,
        extra_headers = extra_headers,
        extra_query = extra_query,
        extra_body = extra_body,
        timeout = timeout,
            )
        return await self._put(
            f"/vm/v1/instance/{instance_krn}",
            body=await async_maybe_transform({"action": action}, v1_perform_action_params.V1PerformActionParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1PerformActionResponse,
        )


class StartStopResourceWithRawResponse:
    def __init__(self, StartStop: StartStopResource) -> None:
        self._StartStop = StartStop

        self.perform_action = to_raw_response_wrapper(
            StartStop.perform_action,
        )


class AsyncStartStopResourceWithRawResponse:
    def __init__(self, StartStop: AsyncStartStopResource) -> None:
        self._StartStop = StartStop

        self.perform_action = async_to_raw_response_wrapper(
            StartStop.perform_action,
        )


class StartStopResourceWithStreamingResponse:
    def __init__(self, StartStop: StartStopResource) -> None:
        self._StartStop = StartStop

        self.perform_action = to_streamed_response_wrapper(
            StartStop.perform_action,
        )


class AsyncStartStopResourceWithStreamingResponse:
    def __init__(self, StartStop: AsyncStartStopResource) -> None:
        self._StartStop = StartStop

        self.perform_action = async_to_streamed_response_wrapper(
            StartStop.perform_action,
        )



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    expiring_certs = client.certs.with_raw_response.get_expiring(
        date = "Enter the Date",
        vpc_id = "Enter the VPC ID"
    )

    print(f"{expiring_certs.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

cluster_krn = "enter the cluster krn"


try:
    create_node_group = client.kks.clusters.node_groups.with_raw_response.create(
        cluster_krn=cluster_krn,
        name="enter the name",
        instance_types="enter the flavor",
        disk_size=100,                                  #update disk size as per requirement
        subnets_krn="enter the krn",
        scaling_config={
            "minSize":1,                               #modify as per requirement
            "maxSize":5,
            "desiredSize":2,

        },
        remote_access={
            "sshKeyKrn":"enter the sshkeykrn",
            "source_security_groups_krns":[]
        },
        node_repair_config={
            "enabled":True
        },  
        labels={},
        taints= []

    )

    print("Successfully created node group")
    print(create_node_group.json())

except Exception as e:
    print(f"Exception: {e}")

        # labels={
        #     "environment": "production",
        #     "team": "backend"
        # },
        # {
        #     "key": "dedicated",
        #     "value": "gpu",
        #     "effect": "NoSchedule"
        # }



# {
#     "nodegroup": {
#         "name": "default-pool",
#         "krn": "krn:kks::6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:nodegroup:673c5749-2f98-45ef-bb1d-6aacb8a7c682",
#         "clusterKrn": "krn:kks:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:cluster:639d2b89-ed93-4951-b1e3-ba0ad4ae110b",
#         "createdAt": 1769083300.062727,
#         "updatedAt": 1769083300.062727,
#         "userUpdatedAt": 1769083300.0621705,
#         "instanceTypes": "CPU-4x-16GB",
#         "labels": {
#             "environment": "productiion"
#         },
#         "remoteAccess": {
#             "sshKeyKrn": "krn:krutrim-ssh:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:sshkey:37876055-60b9-4ce0-b129-157242caad31",
#             "sourceSecurityGroupsKrns": [
#                 "krn:krutrim-sg:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:sg:5fe3fce9-e690-4b5c-97dc-07edabc5f362"
#             ]
#         },
#         "scalingConfig": {
#             "desiredSize": 2,
#             "maxSize": 5,
#             "minSize": 1
#         },
#         "subnetsKrn": "krn:vpc:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:subnet:e74d5566-9e03-4854-b578-0ab5f0c87113",
#         "taints": [
#             {
#                 "effect": "NoSchedule",
#                 "key": "dedicated",
#                 "value": "gpu"
#             }
#         ],
#         "diskSize": 100,
#         "status": "CREATING",
#         "version": "1.34"
#     }
# }
# # try:
# #     create_node_group = client.kks.clusters.node_groups.with_raw_response.create(
# #         cluster_krn=cluster_krn,
# #         name="default-pool34",
# #         instance_types="CPU-4x-16GB",
# #         disk_size=100,
# #         subnets_krn="krn:vpc:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:subnet:00d775d5-8b39-4980-ad8b-eb96374cb6f7",
# #         scaling_config={
# #             "minSize":1,
# #             "maxSize":5,
# #             "desiredSize":2,
# #         },
# #         remote_access={
# #             "source_security_groups_krns":[]
# #         },
# #         node_repair_config={
# #             "enabled":True
# #         },
# #     )

# #     print("Successfully created node group")
# #     print(create_node_group.json())

# # except Exception as e:
# #     print(f"Exception: {e}")




from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcSearchPortsParams"]


class HighlvlvpcSearchPortsParams(TypedDict, total=False):
    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    name: str
    """Filter ports by their name."""

    network_id: str
    """Filter ports by KRN of the network."""

    page: int
    """Page number for pagination."""

    port_id: str
    """Filter ports by KRN of the port."""

    size: int
    """Number of items to return per page."""

    status: str
    """Filter ports by their status."""

    vpc_id: str
    """Filter ports by VPC KRN."""



from __future__ import annotations

from typing import Dict
from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo 


__all__ = ["BucketCreateParams"]


class BucketCreateParams(TypedDict, total=False):
    name: Required[str]
    """The name of the bucket."""

    region: Required[str]
    """The region where the bucket will be created."""

    x_region_id: Required[Annotated[str, PropertyInfo(alias="x-region-id")]]

    anonymous_access: bool
    """Whether anonymous access is allowed for the bucket."""

    description: str
    """A description for the bucket."""

    tags: Dict[str, str]
    """Key-value tags associated with the bucket."""

    versioning: bool
    """Whether versioning is enabled for the bucket."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ...resources.v1.v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from .internal.internal import (
    InternalResource,
    AsyncInternalResource,
    InternalResourceWithRawResponse,
    AsyncInternalResourceWithRawResponse,
    InternalResourceWithStreamingResponse,
    AsyncInternalResourceWithStreamingResponse,
)

__all__ = ["DNSResource", "AsyncDNSResource"]


class DNSResource(SyncAPIResource):
    @cached_property
    def v1(self) -> V1Resource:
        return V1Resource(self._client)

    @cached_property
    def internal(self) -> InternalResource:
        return InternalResource(self._client)

    @cached_property
    def with_raw_response(self) -> DNSResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return DNSResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DNSResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return DNSResourceWithStreamingResponse(self)


class AsyncDNSResource(AsyncAPIResource):
    @cached_property
    def v1(self) -> AsyncV1Resource:
        return AsyncV1Resource(self._client)

    @cached_property
    def internal(self) -> AsyncInternalResource:
        return AsyncInternalResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncDNSResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDNSResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDNSResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return AsyncDNSResourceWithStreamingResponse(self)


class DNSResourceWithRawResponse:
    def __init__(self, dns: DNSResource) -> None:
        self._dns = dns

    @cached_property
    def v1(self) -> V1ResourceWithRawResponse:
        return V1ResourceWithRawResponse(self._dns.v1)

    @cached_property
    def internal(self) -> InternalResourceWithRawResponse:
        return InternalResourceWithRawResponse(self._dns.internal)


class AsyncDNSResourceWithRawResponse:
    def __init__(self, dns: AsyncDNSResource) -> None:
        self._dns = dns

    @cached_property
    def v1(self) -> AsyncV1ResourceWithRawResponse:
        return AsyncV1ResourceWithRawResponse(self._dns.v1)

    @cached_property
    def internal(self) -> AsyncInternalResourceWithRawResponse:
        return AsyncInternalResourceWithRawResponse(self._dns.internal)


class DNSResourceWithStreamingResponse:
    def __init__(self, dns: DNSResource) -> None:
        self._dns = dns

    @cached_property
    def v1(self) -> V1ResourceWithStreamingResponse:
        return V1ResourceWithStreamingResponse(self._dns.v1)

    @cached_property
    def internal(self) -> InternalResourceWithStreamingResponse:
        return InternalResourceWithStreamingResponse(self._dns.internal)


class AsyncDNSResourceWithStreamingResponse:
    def __init__(self, dns: AsyncDNSResource) -> None:
        self._dns = dns

    @cached_property
    def v1(self) -> AsyncV1ResourceWithStreamingResponse:
        return AsyncV1ResourceWithStreamingResponse(self._dns.v1)

    @cached_property
    def internal(self) -> AsyncInternalResourceWithStreamingResponse:
        return AsyncInternalResourceWithStreamingResponse(self._dns.internal)




from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcCreateVpcParams", "Network", "SecurityGroup", "SecurityGroupRule", "Subnet", "Vpc"]


class HighlvlvpcCreateVpcParams(TypedDict, total=False):
    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    network: Network

    security_group: SecurityGroup

    security_group_rule: SecurityGroupRule

    subnet: Subnet

    vpc: Vpc


class Network(TypedDict, total=False):
    admin_state_up: bool
    """Administrative state of the network."""

    name: str
    """Name of the network to be created within the VPC."""


class SecurityGroup(TypedDict, total=False):
    description: str
    """Description for the security group."""

    name: str
    """Name of the default security group to be created."""


class SecurityGroupRule(TypedDict, total=False):
    direction: Literal["ingress", "egress"]
    """Direction of the rule."""

    ethertypes: Literal["IPv4", "IPv6"]
    """Ethertype of the rule."""

    port_max_range: Annotated[int, PropertyInfo(alias="portMaxRange")]
    """Maximum port range."""

    port_min_range: Annotated[int, PropertyInfo(alias="portMinRange")]
    """Minimum port range."""

    protocol: str
    """Protocol for the rule (e.g., tcp, udp, icmp)."""

    remote_ip_prefix: Annotated[str, PropertyInfo(alias="remoteIPPrefix")]
    """Remote IP prefix for the rule."""


class Subnet(TypedDict, total=False):
    cidr: Required[str]
    """CIDR block for the subnet."""

    description: Required[str]
    """Description for the subnet."""

    gateway_ip: Required[str]
    """Gateway IP for the subnet."""

    ip_version: Required[Literal[4, 6]]
    """IP version for the subnet (4 or 6)."""

    name: Required[str]
    """Name of the subnet."""

    egress: Optional[bool]
    """Default egress policy (semantics depend on implementation)."""

    ingress: Optional[bool]
    """Default ingress policy (semantics depend on implementation)."""


class Vpc(TypedDict, total=False):
    description: Required[str]
    """Description for the VPC."""

    enabled: Required[bool]
    """Whether the VPC is enabled."""

    name: Required[str]
    """Name of the VPC."""



from __future__ import annotations

from .pod_create_params import PodCreateParams as PodCreateParams
from .pod_update_params import PodUpdateParams as PodUpdateParams
from .pod_create_response import PodCreateResponse as PodCreateResponse
from .pod_delete_response import PodDeleteResponse as PodDeleteResponse
from .pod_update_response import PodUpdateResponse as PodUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NoneType, NotGiven, NOT_GIVEN
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .clusters.clusters import (
    ClustersResource,
    AsyncClustersResource,
    ClustersResourceWithRawResponse,
    AsyncClustersResourceWithRawResponse,
    ClustersResourceWithStreamingResponse,
    AsyncClustersResourceWithStreamingResponse,
)

__all__ = ["KksResource", "AsyncKksResource"]


class KksResource(SyncAPIResource):
    @cached_property
    def clusters(self) -> ClustersResource:
        return ClustersResource(self._client)

    @cached_property
    def with_raw_response(self) -> KksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return KksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return KksResourceWithStreamingResponse(self)

    def list_addons(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """List All addons"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v1/kks/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list_flavors(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """List flavors"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v1/kks/flavors",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncKksResource(AsyncAPIResource):
    @cached_property
    def clusters(self) -> AsyncClustersResource:
        return AsyncClustersResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncKksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return AsyncKksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return AsyncKksResourceWithStreamingResponse(self)

    async def list_addons(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """List All addons"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/kks/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list_flavors(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """List flavors"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/kks/flavors",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class KksResourceWithRawResponse:
    def __init__(self, kks: KksResource) -> None:
        self._kks = kks

        self.list_addons = to_raw_response_wrapper(
            kks.list_addons,
        )
        self.list_flavors = to_raw_response_wrapper(
            kks.list_flavors,
        )

    @cached_property
    def clusters(self) -> ClustersResourceWithRawResponse:
        return ClustersResourceWithRawResponse(self._kks.clusters)


class AsyncKksResourceWithRawResponse:
    def __init__(self, kks: AsyncKksResource) -> None:
        self._kks = kks

        self.list_addons = async_to_raw_response_wrapper(
            kks.list_addons,
        )
        self.list_flavors = async_to_raw_response_wrapper(
            kks.list_flavors,
        )

    @cached_property
    def clusters(self) -> AsyncClustersResourceWithRawResponse:
        return AsyncClustersResourceWithRawResponse(self._kks.clusters)


class KksResourceWithStreamingResponse:
    def __init__(self, kks: KksResource) -> None:
        self._kks = kks

        self.list_addons = to_streamed_response_wrapper(
            kks.list_addons,
        )
        self.list_flavors = to_streamed_response_wrapper(
            kks.list_flavors,
        )

    @cached_property
    def clusters(self) -> ClustersResourceWithStreamingResponse:
        return ClustersResourceWithStreamingResponse(self._kks.clusters)


class AsyncKksResourceWithStreamingResponse:
    def __init__(self, kks: AsyncKksResource) -> None:
        self._kks = kks

        self.list_addons = async_to_streamed_response_wrapper(
            kks.list_addons,
        )
        self.list_flavors = async_to_streamed_response_wrapper(
            kks.list_flavors,
        )

    @cached_property
    def clusters(self) -> AsyncClustersResourceWithStreamingResponse:
        return AsyncClustersResourceWithStreamingResponse(self._kks.clusters)



from typing import Optional

from krutrim_client._models import BaseModel  


__all__ = ["BucketCreateResponse"]


class BucketCreateResponse(BaseModel):
    
    krn: Optional[str] = None
    bucketName: Optional[str] = None
    createdAt: Optional[str] = None



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    delete_node_group = client.kks.clusters.node_groups.with_raw_response.delete(
        cluster_krn = "enter the cluster krn",
        nodegroup_krn = "enter the node group krn",
    )

    print(f"Successfully deleted the node group" )

except Exception as e:
    print(f"Exception: {e}")



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)

try:

    update_cert_response = client.tags.with_raw_response.updateCertificate(

        path_cert_id = "Enter the Certificate ID",
        cert_file = "Enter the Certificate File Path",

        # form fields
        flag="0",    # use "0" or "1" as required

        # headers

        vpc_id="Enter the VPC ID",
    )

    print(f"{update_cert_response.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")




# try:

#     import_cert_resp = client.tags.with_raw_response.updateCertificate(

#         path_cert_id = "krn:kcm:colo-1:1330618268:64151bfb-efcc-4c55-914e-1e497c7fb602:certs:72aa120f-528e-40ac-bb93-0879be212d16",
#         cert_file = "/Users/bhanu.singh3/Documents/DEV/krutrim-client-sdk/bundle.p12",

#         # form fields
#         flag="0",    # use "0" or "1" as required

#         # headers

#         vpc_id="krn:vpc:colo-1:1330618268:64151bfb-efcc-4c55-914e-1e497c7fb602:vpc:8334f527-38e2-48d2-a7b5-a680bea0ca9a",
#     )

#     print(f"{import_cert_resp.json()}")

# except Exception as e:
#     print(f"Error has occurred: {e}")







import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    krn_by_vpc = client.asg.with_raw_response.get_asg_krn_by_vpc(
        page = 1,
        size = 100,
        vpc_krn = "Enter the vpc KRN ID"
    )

    print(f"{krn_by_vpc.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


from __future__ import annotations


from .access_keys_create_params import AccessKeyCreateParams as AccessKeyCreateParams
from .access_keys_list_response import AccessKeyListResponse as AccessKeyListResponse
from .access_keys_create_response import AccessKeyCreateResponse as AccessKeyCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from .vpc import (
    VpcResource,
    AsyncVpcResource,
    VpcResourceWithRawResponse,
    AsyncVpcResourceWithRawResponse,
    VpcResourceWithStreamingResponse,
    AsyncVpcResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.dns.v1 import zone_create_params

__all__ = ["ZoneResource", "AsyncZoneResource"]


class ZoneResource(SyncAPIResource):
    @cached_property
    def vpc(self) -> VpcResource:
        return VpcResource(self._client)

    @cached_property
    def with_raw_response(self) -> ZoneResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return ZoneResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ZoneResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return ZoneResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        subnetid: str | Omit = omit,
        type: Literal["public", "private"] | Omit = omit,
        vpcid: str | Omit = omit,
        zonename: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Public or Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/dns/v1/zone",
            body=maybe_transform(
                {
                    "subnetid": subnetid,
                    "type": type,
                    "vpcid": vpcid,
                    "zonename": zonename,
                },
                zone_create_params.ZoneCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/dns/v1/zone/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    def fetch(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/zones",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    

    def fetchZoneById(
        self,
        zoneid:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/zone/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

class AsyncZoneResource(AsyncAPIResource):
    @cached_property
    def vpc(self) -> AsyncVpcResource:
        return AsyncVpcResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncZoneResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return AsyncZoneResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncZoneResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return AsyncZoneResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        subnetid: str | Omit = omit,
        type: Literal["public", "private"] | Omit = omit,
        vpcid: str | Omit = omit,
        zonename: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Public or Private Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/dns/v1/zone",
            body=await async_maybe_transform(
                {
                    "subnetid": subnetid,
                    "type": type,
                    "vpcid": vpcid,
                    "zonename": zonename,
                },
                zone_create_params.ZoneCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/dns/v1/zone/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    async def fetch(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/zones",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    

    async def fetchZoneById(
        self,
        zoneid:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/zone/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

class ZoneResourceWithRawResponse:
    def __init__(self, zone: ZoneResource) -> None:
        self._zone = zone

        self.create = to_raw_response_wrapper(
            zone.create,
        )
        self.delete = to_raw_response_wrapper(
            zone.delete,
        )
        self.fetch = to_raw_response_wrapper(
            zone.fetch,
        )
        self.fetchZoneById = to_raw_response_wrapper(
            zone.fetchZoneById,
        )
    @cached_property
    def vpc(self) -> VpcResourceWithRawResponse:
        return VpcResourceWithRawResponse(self._zone.vpc)


class AsyncZoneResourceWithRawResponse:
    def __init__(self, zone: AsyncZoneResource) -> None:
        self._zone = zone

        self.create = async_to_raw_response_wrapper(
            zone.create,
        )
        self.delete = async_to_raw_response_wrapper(
            zone.delete,
        )
        self.fetch = async_to_raw_response_wrapper(
            zone.fetch,
        )
        self.fetchZoneById = async_to_raw_response_wrapper(
            zone.fetchZoneById,
        )
    @cached_property
    def vpc(self) -> AsyncVpcResourceWithRawResponse:
        return AsyncVpcResourceWithRawResponse(self._zone.vpc)


class ZoneResourceWithStreamingResponse:
    def __init__(self, zone: ZoneResource) -> None:
        self._zone = zone

        self.create = to_streamed_response_wrapper(
            zone.create,
        )
        self.delete = to_streamed_response_wrapper(
            zone.delete,
        )
        self.fetch = to_streamed_response_wrapper(
            zone.fetch,
        )
        self.fetchZoneById = to_streamed_response_wrapper(
            zone.fetchZoneById,
        )
    @cached_property
    def vpc(self) -> VpcResourceWithStreamingResponse:
        return VpcResourceWithStreamingResponse(self._zone.vpc)


class AsyncZoneResourceWithStreamingResponse:
    def __init__(self, zone: AsyncZoneResource) -> None:
        self._zone = zone

        self.create = async_to_streamed_response_wrapper(
            zone.create,
        )
        self.delete = async_to_streamed_response_wrapper(
            zone.delete,
        )
        self.fetch = async_to_streamed_response_wrapper(
            zone.fetch,
        )
        self.fetchZoneById = async_to_streamed_response_wrapper(
            zone.fetchZoneById,
        )
    @cached_property
    def vpc(self) -> AsyncVpcResourceWithStreamingResponse:
        return AsyncVpcResourceWithStreamingResponse(self._zone.vpc)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from typing import Mapping, cast, Dict

from ..._types import Body, Omit, Query, Headers, NoneType, FileTypes, NotGiven, NOT_GIVEN,omit
from ..._utils import maybe_transform, async_maybe_transform, deepcopy_minimal, extract_files
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.kcm import tag_list_params, tag_update_params
from ..._base_client import make_request_options

__all__ = ["TagsResource", "AsyncTagsResource"]


class TagsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kcm1-python#accessing-raw-response-data-eg-headers
        """
        return TagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kcm1-python#with_streaming_response
        """
        return TagsResourceWithStreamingResponse(self)

    def updateCertificate(
        self,
        *,
        path_cert_id: str,
        cert_file: FileTypes | Omit = omit,
        vpc_id: str,
        flag: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """6.

        Update Tags (JSON)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*","X-Vpc-Id": vpc_id, **(extra_headers or {})}

        from os import PathLike
        if cert_file is not omit and isinstance(cert_file, (str, PathLike)):
            cert_file = open(str(cert_file), "rb")

        body = deepcopy_minimal(
            {
                "certFile": cert_file,
                "flag": flag
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["certFile"]])
        extra_headers["Content-Type"] = "multipart/form-data"

        if not path_cert_id:
            raise ValueError(f"Expected a non-empty value for `path_cert_id` but received {path_cert_id!r}")
        return self._put(
            f"/kcm/v1/certs/{path_cert_id}",
            body=maybe_transform(body, tag_update_params.TagUpdateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    
    def addCertificateTag(
        self,
        *,
        path_cert_id: str,
        tags: Dict[str, str],
        extra_headers: Headers | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """7.

        add tags (JSON)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        if not path_cert_id:
            raise ValueError(f"Expected a non-empty value for `path_cert_id` but received {path_cert_id!r}")

        return self._post(
            f"/kcm/v1/certs/tags/{path_cert_id}",
            body=tags,
            options=make_request_options(
                extra_headers=extra_headers,
                timeout=timeout,
            ),
            cast_to=None,
        )

    def getTagValue (
        self,
        *,
        cert_id: str,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """8.

        Get Tag Value

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/kcm/v1/certs/tags",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "cert_id": cert_id,
                        "tag_name": tag_name,
                    },
                    tag_list_params.TagListParams,
                ),
            ),
            cast_to=NoneType,
        )
    
    


class AsyncTagsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kcm1-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kcm1-python#with_streaming_response
        """
        return AsyncTagsResourceWithStreamingResponse(self)

    async def updateCertificate(
        self,
        *,
        path_cert_id: str,
        cert_file: FileTypes | Omit = omit,
        vpc_id: str,
        flag: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """6.

        Update Tags (JSON)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*","X-Vpc-Id": vpc_id, **(extra_headers or {})}

        from os import PathLike
        if cert_file is not omit and isinstance(cert_file, (str, PathLike)):
            cert_file = open(str(cert_file), "rb")

        body = deepcopy_minimal(
            {
                "certFile": cert_file,
                "flag": flag
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["certFile"]])
        extra_headers["Content-Type"] = "multipart/form-data"

        if not path_cert_id:
            raise ValueError(f"Expected a non-empty value for `path_cert_id` but received {path_cert_id!r}")
        return await self._put(
            f"/kcm/v1/certs/{path_cert_id}",
            body=await async_maybe_transform(body, tag_update_params.TagUpdateParams),
            files=files,
            options= make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )
    
    async def addCertificateTag(
        self,
        *,
        path_cert_id: str,
        tags: Dict[str, str],
        extra_headers: Headers | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """7.

        add tags (JSON)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        if not path_cert_id:
            raise ValueError(f"Expected a non-empty value for `path_cert_id` but received {path_cert_id!r}")

        return await self._post(
            f"/kcm/v1/certs/tags/{path_cert_id}",
            body=tags,
            options=make_request_options(
                extra_headers=extra_headers,
                timeout=timeout,
            ),
            cast_to=None,
        )

    async def getTagValue(
        self,
        *,
        cert_id: str,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """7.

        Get Tag Value

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/kcm/v1/certs/tags",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "cert_id": cert_id,
                        "tag_name": tag_name,
                    },
                    tag_list_params.TagListParams,
                ),
            ),
            cast_to=NoneType,
        )


class TagsResourceWithRawResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.updateCertificate = to_raw_response_wrapper(
            tags.updateCertificate,
        )
        self.getTagValue = to_raw_response_wrapper(
            tags.getTagValue,
        )
        self.addCertificateTag = to_raw_response_wrapper(
            tags.addCertificateTag,
        )


class AsyncTagsResourceWithRawResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.updateCertificate = async_to_raw_response_wrapper(
            tags.updateCertificate,
        )
        self.getTagValue = async_to_raw_response_wrapper(
            tags.getTagValue,
        )
        self.addCertificateTag = async_to_raw_response_wrapper(
            tags.addCertificateTag,
        )


class TagsResourceWithStreamingResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.updateCertificate = to_streamed_response_wrapper(
            tags.updateCertificate,
        )
        self.getTagValue = to_streamed_response_wrapper(
            tags.getTagValue,
        )
        self.addCertificateTag = to_streamed_response_wrapper(
            tags.addCertificateTag,
        )


class AsyncTagsResourceWithStreamingResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.updateCertificate = async_to_streamed_response_wrapper(
            tags.updateCertificate,
        )
        self.getTagValue = async_to_streamed_response_wrapper(
            tags.getTagValue,
        )
        self.addCertificateTag = async_to_streamed_response_wrapper(
            tags.addCertificateTag,
        )


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ZoneCreateParams"]


class ZoneCreateParams(TypedDict, total=False):
    subnetid: str

    type: Literal["public", "private"]

    vpcid: str

    zonename: str



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    create_security_group_rules_resp = client.securityGroup.create_rule(
        direction= "ingress",
        ethertypes = "ipv4",
        port_max_range = 222,
        port_min_range =100,
        protocol = "TCP",
        remote_ip_prefix = "192.168.0.1/24",
        vpcid = "Enter the VPC ID",
        timeout = 1000,
        x_region = "Enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Security Group Rules created successfully:{create_security_group_rules_resp}")

    securtiy_group_rule_id  = create_security_group_rules_resp.result['id']

    attach_security_group_rule_resp = client.securityGroup.attach_rule(
        ruleid = securtiy_group_rule_id,
        securityid = "Enter the security group ID",
        vpcid = "Enter the VCP ID",
        x_region = "Enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully attched the security group rules:  {attach_security_group_rule_resp}")
except Exception as e:
    print(f"Error has occured: {e}")


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    get_templates = client.asg.v1.with_raw_response.get_launch_templates(
        vpc_id="Enter the VPC KRN ID",
        page=1,
        size=100,
        x_region="Enter the Region"
    )

    print(f"{get_templates.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")



from __future__ import annotations

from typing import List, Union, Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._types import Base64FileInput
from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcCreateInstanceParams"]


class HighlvlvpcCreateInstanceParams(TypedDict, total=False):
    image_krn: Required[str]

    instance_name: Required[Annotated[str, PropertyInfo(alias="instanceName")]]

    instance_type: Required[Annotated[str, PropertyInfo(alias="instanceType")]]

    network_id: Required[str]

    region: Required[str]

    security_groups: Required[List[str]]

    sshkey_name: Required[str]

    subnet_id: Required[str]

    vm_volume_disk_size: Required[str]

    vpc_id: Required[str]

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    floating_ip: bool

    security_group_rules_name: str

    security_group_rules_port: str

    security_group_rules_protocol: str

    user_data: Annotated[Union[str, Base64FileInput], PropertyInfo(format="base64")]

    volume_name: Optional[str]

    volume_size: Optional[str]
